@@ -2,9 +2,9 @@
 /**
  * MediaWiki math extension
  *
- * (c) 2002-2012 Tomasz Wegrzanowski, Brion Vibber, Moritz Schubotz,
+ * @copyright 2002-2012 Tomasz Wegrzanowski, Brion Vibber, Moritz Schubotz,
  * and other MediaWiki contributors
- * GPLv2 license; info in main package.
+ * @license GPL-2.0-or-later
  *
  * @file
  */
@@ -29,10 +29,12 @@ abstract class MathRenderer {
 	protected $mathml = '';
 	/** @var string SVG layout only (no semantics) */
 	protected $svg = '';
+	/** @var string PNG  image only (no semantics) */
+	protected $png = '';
 	/** @var string the original user input string (which was used to calculate the inputhash) */
 	protected $userInputTex = '';
 	// FURTHER PROPERTIES OF THE MATHEMATICAL CONTENT
-	/** @var ('inlineDisplaystyle'|'display'|'inline'|'linebreak') the rendering style */
+	/** @var string ('inlineDisplaystyle'|'display'|'inline'|'linebreak') the rendering style */
 	protected $mathStyle = 'inlineDisplaystyle';
 	/** @var array with userdefined parameters passed to the extension (not used) */
 	protected $params = [];
@@ -119,7 +121,6 @@ abstract class MathRenderer {
 	}
 
 	/**
-	 *
 	 * @param string $md5
 	 * @return MathRenderer the MathRenderer generated from md5
 	 */
@@ -141,7 +142,7 @@ abstract class MathRenderer {
 	 * @return MathRenderer appropriate renderer for mode
 	 */
 	public static function getRenderer( $tex, $params = [], $mode = 'png' ) {
-		global $wgDefaultUserOptions, $wgMathEnableExperimentalInputFormats;
+		global $wgDefaultUserOptions, $wgMathEnableExperimentalInputFormats, $wgMathoidCli;
 
 		if ( isset( $params['forcemathmode'] ) ) {
 			$mode = $params['forcemathmode'];
@@ -173,7 +174,11 @@ abstract class MathRenderer {
 				break;
 			case 'mathml':
 			default:
-				$renderer = new MathMathML( $tex, $params );
+				if ( $wgMathoidCli ) {
+					$renderer = new MathMathMLCli( $tex, $params );
+				} else {
+					$renderer = new MathMathML( $tex, $params );
+				}
 		}
 		LoggerFactory::getInstance( 'Math' )->debug( 'Start rendering $' . $renderer->tex .
 			'$ in mode ' . $mode );
@@ -198,7 +203,7 @@ abstract class MathRenderer {
 	 * Returns an internationalized HTML error string
 	 *
 	 * @param string $msg message key for specific error
-	 * @internal param \Varargs $parameters (optional) zero
+	 * @note param \Varargs $parameters (optional) zero
 	 * or more message parameters for specific error
 	 *
 	 * @return string HTML error string
@@ -227,7 +232,6 @@ abstract class MathRenderer {
 	/**
 	 * Set the input hash (if user input tex is not available)
 	 * @param string $md5
-	 * @return string hash
 	 */
 	public function setMd5( $md5 ) {
 		$this->md5 = $md5;
@@ -241,7 +245,7 @@ abstract class MathRenderer {
 	public function getInputHash() {
 		// TODO: What happens if $tex is empty?
 		if ( !$this->inputHash ) {
-			$dbr = wfGetDB( DB_SLAVE );
+			$dbr = wfGetDB( DB_REPLICA );
 			return $dbr->encodeBlob( pack( "H32", $this->getMd5() ) ); # Binary packed, not hex
 		}
 		return $this->inputHash;
@@ -253,7 +257,7 @@ abstract class MathRenderer {
 	 * @return string md5
 	 */
 	private static function dbHash2md5( $hash ) {
-		$dbr = wfGetDB( DB_SLAVE );
+		$dbr = wfGetDB( DB_REPLICA );
 		$xhash = unpack( 'H32md5', $dbr->decodeBlob( $hash ) . "                " );
 		return $xhash['md5'];
 	}
@@ -264,7 +268,7 @@ abstract class MathRenderer {
 	 * @return bool true if read successfully, false otherwise
 	 */
 	public function readFromDatabase() {
-		$dbr = wfGetDB( DB_SLAVE );
+		$dbr = wfGetDB( DB_REPLICA );
 		$rpage = $dbr->selectRow( $this->getMathTableName(),
 			$this->dbInArray(),
 			[ 'math_inputhash' => $this->getInputHash() ],
@@ -325,7 +329,7 @@ abstract class MathRenderer {
 	 * to the database even if they are empty.
 	 *
 	 * This function can be seen as protected function.
-	 * @param DatabaseBase $dbw
+	 * @param \Wikimedia\Rdbms\IDatabase $dbw
 	 */
 	public function writeToDatabase( $dbw = null ) {
 		# Now save it back to the DB:
@@ -550,7 +554,6 @@ abstract class MathRenderer {
 	}
 
 	/**
-	 *
 	 * @param string $mathStyle ('inlineDisplaystyle'|'display'|'inline')
 	 */
 	public function setMathStyle( $mathStyle = 'display' ) {
@@ -706,4 +709,12 @@ abstract class MathRenderer {
 		$this->lastError = $checker->getError();
 		return false;
 	}
+
+	/**
+	 * @return string
+	 */
+	public function getPng() {
+		return $this->png;
+	}
+
 }
